#!/bin/bash

# Description: Controls service start/stop operations with additional checks.
# Parameters:
#   --help or -h - Display help information

# Function to display usage and parameters
show_help()
{
    echo -e "\n\033[32mScript Usage Help:\033[0m"
    echo "Usage: $(basename $0) [on|off] [--help|-h]"
    echo ""
    echo "\033[34mParameter Description:\033[0m"
    echo "  on        - Start the iac service"
    echo "  off       - Stop the iac service"
    echo "  --help, -h - Show this help message"
}

check_iac()
{
    if grep -q '\<iac=1\>' /proc/cmdline; then
        return 0
    else
        return 1
    fi
}

# Check for help parameter
if [[ "$1" == "--help" || "$1" == "-h" ]]; then
    show_help
    exit 0
elif ! check_iac; then
    echo -e "\n\033[32mPlease configure the kernel boot parameter \"iac=1\" first, and then restart the system.\033[0m"
    exit 1
elif [[ "$1" == "on" ]]; then
    # Start service operation
    echo -e "\n\033[32mStarting services...\033[0m"
    
    # Check if all required files exist and are executable
    for file in /usr/libexec/iac/iaclabel /usr/bin/setfattr /sys/module/iac/parameters/iac_mode; do
        if [[ ! -e "$file" ]]; then
            echo -e "\033[31mError: File $file does not exist or is not executable\033[0m"
            exit 1
        fi
    done
    
    if ! getfattr -dn "trusted.iac" /tmp /dev/{shm,null,tty} 2>/dev/null| grep -qw "\<on\>"; then
		echo "2" > /sys/module/iac/parameters/iac_mode
		/usr/libexec/iac/iaclabel set &> /dev/null
		/usr/bin/setfattr -hn security.iac -v"1" /tmp /var/tmp /dev/{shm,null,tty}
		/usr/bin/setfattr -hn trusted.iac -v"on" /tmp /var/tmp /dev/{shm,null,tty}
    fi
    echo "1" > /sys/module/iac/parameters/iac_mode

    echo -e "\n\033[32mService start completed successfully.\033[0m"
elif [[ "$1" == "off" ]]; then
    # Stop service operation
    echo -e "\n\033[32mStopping services...\033[0m"
    echo 0 > /sys/module/iac/parameters/iac_mode
else
    # Invalid parameter, display help
    show_help
    exit 2
fi
